/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.site.apio.internal.model;

import com.liferay.portal.kernel.model.Group;
import com.liferay.portal.kernel.theme.ThemeDisplay;

/**
 * Group wrapper that includes a {@code ThemeDisplay} object to allow getting
 * the different absolute URLs.
 *
 * @author Eduardo Perez
 * @review
 */
public class GroupWrapper extends com.liferay.portal.kernel.model.GroupWrapper {

	public GroupWrapper(Group group, ThemeDisplay themeDisplay) {
		super(group);

		_themeDisplay = themeDisplay;
	}

	/**
	 * Returns the group's private URL.
	 *
	 * @return the private URL
	 * @review
	 */
	public String getPrivateURL() {
		return _getDisplayURL(true);
	}

	/**
	 * Returns the group's public URL.
	 *
	 * @return the public URL
	 * @review
	 */
	public String getPublicURL() {
		return _getDisplayURL(false);
	}

	private String _getDisplayURL(boolean isPrivate) {
		return getDisplayURL(_themeDisplay, isPrivate);
	}

	private final ThemeDisplay _themeDisplay;

}